@@ -45,7 +45,7 @@ import javax.jms.TextMessage;
 import org.apache.cxf.Bus;
 import org.apache.cxf.BusFactory;
 import org.apache.cxf.common.logging.LogUtils;
-import org.apache.cxf.configuration.ConfigurationException;
+import org.apache.cxf.common.util.StringUtils;
 import org.apache.cxf.continuations.ContinuationProvider;
 import org.apache.cxf.continuations.SuspendedInvocationException;
 import org.apache.cxf.helpers.CastUtils;
@@ -100,11 +100,11 @@ public class JMSDestination extends AbstractMultiplexDestination implements Mess
     public void activate() {
         getLogger().log(Level.INFO, "JMSDestination activate().... ");
         String name = endpointInfo.getName().toString() + ".jms-destination";
-        if (jmsConfig.getTargetDestination() == null || jmsConfig.getConnectionFactory() == null) {
-            throw new ConfigurationException(
-                new org.apache.cxf.common.i18n.Message("INSUFFICIENT_CONFIGURATION_DESTINATION", LOG, name));
-        }
-        jmsListener = JMSFactory.createJmsListener(jmsConfig, this, jmsConfig.getTargetDestination());
+        org.apache.cxf.common.i18n.Message msg = 
+            new org.apache.cxf.common.i18n.Message("INSUFFICIENT_CONFIGURATION_DESTINATION", LOG, name);
+        jmsConfig.ensureProperlyConfigured(msg);
+        jmsListener = JMSFactory.createJmsListener(jmsConfig, this, jmsConfig.getTargetDestination(),
+                                                   null, true);
     }
 
     public void deactivate() {
@@ -135,6 +135,8 @@ public class JMSDestination extends AbstractMultiplexDestination implements Mess
             return resolveDestinationName(jmsTemplate, replyToName);
         } else if (message.getJMSReplyTo() != null) {
             return message.getJMSReplyTo();
+        } else if (!StringUtils.isEmpty(jmsConfig.getReplyDestination())) {
+            return resolveDestinationName(jmsTemplate, jmsConfig.getReplyDestination());
         } else {
             throw new RuntimeException("No replyTo destination set on request message or cxf message");
         }
@@ -176,6 +178,7 @@ public class JMSDestination extends AbstractMultiplexDestination implements Mess
             inMessage.setContent(InputStream.class, new ByteArrayInputStream(request));
             inMessage.put(JMSConstants.JMS_SERVER_RESPONSE_HEADERS, new JMSMessageHeadersType());
             inMessage.put(JMSConstants.JMS_REQUEST_MESSAGE, message);
+            inMessage.put(Message.SKIP_PRE_REQUEST_ACK, Boolean.TRUE);
             inMessage.setDestination(this);
 
             inMessage.put(ContinuationProvider.class.getName(), 
